@@ -17,7 +17,10 @@ async fn main() {
     let url: Url = Url::from_str(url_string.as_str()).unwrap();
     let url: Url = url.join(".well-known/jwks.json").unwrap();
 
-    let source: WebSource = WebSource::new(url);
+    let source: WebSource = WebSource::builder()
+        .build(url)
+        .expect("Failed to build WebSource");
+
     let client: JwksClient<WebSource> = JwksClient::new(source);
 
     // The kid "unknown" cannot be a JWKS valid KID. This must not be found here
